import {
  select, 
  json, 
  geoPath,
  geoCentroid,
  geoAlbersUsa,
  zoom,
  event,
  scaleSqrt,
  max,
} from 'd3';

import { feature, merge } from 'topojson';
import { loadAndProcessData } from './loadAndProcessData';
import { usMap } from './usMap';

const svg = select('svg');
const usMapg = svg.append('g');

const width = +svg.attr('width');
const height = +svg.attr('height');

const g = svg.append('g');

let data;
let date;
let dates;
let sizeScale = null;
let selection;

const stateMap = geoAlbersUsa();
const pathGenerator = map => geoPath().projection(map);
const radiusValue = d => d.properties['TotalVolume'];

loadAndProcessData().then(props => {  
  data = props[0];
  dates = props[1];
  sizeScale = scaleSqrt()
    .domain([0, max(data.features, radiusValue)])
    .range([0, 4]);
  
  render(data,dates);
});


const render = (data,dates) => { 
  usMapg.call(usMap,{
    pathGenerator,
    stateMap,
    data,
    sizeScale,
    radiusValue,
    svg
  });
  
  g.append("g")
    .attr("class","slider")
    .selectAll('rect').data([null])
    .enter().append('rect')
    .attr('x',50)
    .attr('y',height*0.875)
    .attr('width',width-100)
    .attr('height',20)
    .attr('fill','none')
    .attr('stroke','black')
    .attr('stroke-width','3')

};     



